@@ -1,10 +1,10 @@
 from aiohttp import web as aio_web
 
 from bolinette import env
-from bolinette.routing import web
+from bolinette.web import resources
 from bolinette.commands import command
 
 
 @command('run_server')
 def run_server():
-    aio_web.run_app(web.app, port=env['PORT'])
+    aio_web.run_app(resources.app, port=env['PORT'])
