@@ -1,5 +1,4 @@
-from bolinette import response
-from bolinette.routing import Namespace, Method
+from bolinette.web import response, Namespace, Method
 from bolinette.services import timezone_service
 
 ns = Namespace('/tz', timezone_service)
